# August 31, 2023 - Version 1.2.0

## Summary

---

**🔗 BREAKING CHANGES: Dataitems Retrieval**

**⚡️ Risk Model Added**

**✈️ CIQ Product, CIQ Business Relationship, CIQ Company Intelligence, CIQ Transaction M&A Package Integrated**


Please update PrismStudio via

```python
pip install prismstudio --upgrade
```

or

```python
pip install prismstudio==1.2.0
```

## August 31, 2023 -
PrismStudio 1.2.0

---

### FEATURES

- **New Feature: S&P CapitalIQ Product Package**
    PrismStudio now includes S&P CapitalIQ Product Package, through a new component: [Product Component](<#prism.company.product>)

- **New Feature: S&P CapitalIQ Business Relationship Package**
    PrismStudio now includes S&P CapitalIQ Business Relationship Package, through a new component: [Business Relationship Component](<#prism.company.relationship>)

- **New Feature: S&P CapitalIQ Company Intelligence Package**
    PrismStudio now includes S&P CapitalIQ Company Intelligence Package, through two new components:
        [Description Component](<#prism.company.description>)
        [Competitor Component](<#prism.company.competitor>)

- **New Feature: S&P CapitalIQ Transaction M&A Package**
    PrismStudio now includes S&P CapitalIQ Transaction M&A, through two new components:
        [M&A Component](<#prism.transaction.ma>)
        [Buyback Component](<#prism.transaction.buyback>)

- **New Feature: Risk Cost Model Category**
    We are excited to introduce the Risk Model as a part of PrismStudio's latest Model Category. The Risk Model offers you an advanced analytical approach to quantify and mitigate risks associated with interdependent asset movements.

    [QIS](<#prism.riskmodel.qis>): Nonlinear shrinkage derived under Frobenius loss and its two cousins, Inverse Stein’s loss and Minimum Variance loss, called quadratic-inverse shrinkage (QIS). See Ledoit and Wolf (2021, Section 4.5). 

    Ledoit, O. and Wolf, M. (2022). Quadratic shrinkage for large covariance matrices. Bernoulli. Available online at https://www.econ.uzh.ch/en/people/faculty/wolf/publications.html.

### IMPROVEMENTS

- **Breaking Changes: Dataitems Retrieval**
    We're pleased to announce a significant update to the PrismStudio that introduces a more consistent and streamlined syntax across various modules. This release brings about changes in the way dataitems are accessed, reflecting our commitment to enhancing the usability and coherence of the PrismStudio Client. However, please be aware that these changes will require modifications to your existing code. Here are the details of the breaking syntax changes:

    Old Syntax Example:
    ```
    >>> com_di = prism.financial.commitment_dataitems()
    >>> est_di = prism.estimate.consensus_dataitems()
    ```

    New Syntax Example:
    ```
    >>> com_di = prism.financial.commitment.dataitems()
    >>> est_di = prism.estimate.consensus.dataitems()
    ```

    Action Required:
    To accommodate these syntax changes, you'll need to update your existing codebase wherever data items are accessed across different modules. Replace the previous _dataitems() method with the new .dataitems() method, as demonstrated in the new syntax examples provided above.

    We understand that adapting to changes in syntax can involve some adjustments, but we believe these updates will ultimately lead to more maintainable and comprehensible code. Should you have any questions or require assistance during this transition, please feel free to reach out to our dedicated support team.